@@ -1,6 +1,7 @@
 """Tests for installer.utils
 """
 
+import base64
 import hashlib
 import textwrap
 from email.message import Message
@@ -93,10 +94,14 @@ class TestParseWheelFilename:
             parse_wheel_filename(string)
 
 
-class TestCopyFileObjWithHashing(object):
+class TestCopyFileObjWithHashing:
     def test_basic_functionality(self):
         data = b"input data is this"
-        hash_ = hashlib.sha256(data).hexdigest()
+        hash_ = (
+            base64.urlsafe_b64encode(hashlib.sha256(data).digest())
+            .decode("ascii")
+            .rstrip("=")
+        )
         size = len(data)
 
         with BytesIO(data) as source:
@@ -112,21 +117,25 @@ class TestScript:
     @pytest.mark.parametrize(
         ("data", "expected"),
         [
-            (
+            pytest.param(
                 b"#!python\ntest",
                 b"#!/my/python\ntest",
+                id="python",
             ),
-            (
+            pytest.param(
                 b"#!pythonw\ntest",
                 b"#!/my/python\ntest",
+                id="pythonw",
             ),
-            (
+            pytest.param(
                 b"#!python something\ntest",
                 b"#!/my/python\ntest",
+                id="python-with-args",
             ),
-            (
+            pytest.param(
                 b"#!python",
                 b"#!/my/python\n",
+                id="python-no-content",
             ),
         ],
     )
@@ -156,7 +165,8 @@ class TestScript:
 class TestConstructRecord:
     def test_construct(self):
         records = [
-            RecordEntry.from_elements(*elements) for elements, _, _ in SAMPLE_RECORDS
+            (scheme, RecordEntry.from_elements(*elements))
+            for scheme, elements, _, _ in SAMPLE_RECORDS
         ]
         assert construct_record_file(records).read() == (
             b"test1.py,sha256=Y0sCextp4SQtQNU-MSs7SsdxD1W-gfKJtUlEbvZ3i-4,6\n"
@@ -172,34 +182,37 @@ class TestParseEntryPoints:
     @pytest.mark.parametrize(
         ("script", "expected"),
         [
-            (u"", []),
-            (
-                u"""
+            pytest.param("", [], id="empty"),
+            pytest.param(
+                """
                     [foo]
                     foo = foo.bar
                 """,
                 [],
+                id="unrelated",
             ),
-            (
-                u"""
+            pytest.param(
+                """
                     [console_scripts]
                     package = package.__main__:package
                 """,
                 [
                     ("package", "package.__main__", "package", "console"),
                 ],
+                id="cli",
             ),
-            (
-                u"""
+            pytest.param(
+                """
                     [gui_scripts]
                     package = package.__main__:package
                 """,
                 [
                     ("package", "package.__main__", "package", "gui"),
                 ],
+                id="gui",
             ),
-            (
-                u"""
+            pytest.param(
+                """
                     [console_scripts]
                     magic-cli = magic.cli:main
 
@@ -210,6 +223,7 @@ class TestParseEntryPoints:
                     ("magic-cli", "magic.cli", "main", "console"),
                     ("magic-gui", "magic.gui", "main", "gui"),
                 ],
+                id="cli-and-gui",
             ),
         ],
     )
